@@ -40,6 +40,17 @@ def test_update_query_with_multiple_args():
         url.update_query("a", "b")
 
 
+def test_update_query_with_none_arg():
+    url = URL("http://example.com/?foo=bar&baz=foo")
+    expected_url = URL("http://example.com/")
+    assert url.update_query(None) == expected_url
+
+
+def test_update_query_with_empty_dict():
+    url = URL("http://example.com/?foo=bar&baz=foo")
+    assert url.update_query({}) == url
+
+
 def test_with_query_list_of_pairs():
     url = URL("http://example.com")
     assert str(url.with_query([("a", "1")])) == "http://example.com/?a=1"
@@ -48,7 +59,7 @@ def test_with_query_list_of_pairs():
 def test_with_query_list_non_pairs():
     url = URL("http://example.com")
     with pytest.raises(ValueError):
-        url.with_query(["a=1", "b=2" "c=3"])
+        url.with_query(["a=1", "b=2", "c=3"])
 
 
 def test_with_query_kwargs():
